netapp_ontap.models.fpolicy_event_file_operations API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.fpolicy_event_file_operations`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class FpolicyEventFileOperationsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the FpolicyEventFileOperations object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `access: bool GET POST PATCH`

    Access operations

  `close: bool GET POST PATCH`

    File close operations

  `create: bool GET POST PATCH`

    File create operations

  `create_dir: bool GET POST PATCH`

    Directory create operations

  `delete: bool GET POST PATCH`

    File delete operations

  `delete_dir: bool GET POST PATCH`

    Directory delete operations

  `getattr: bool GET POST PATCH`

    Get attribute operations

  `link: bool GET POST PATCH`

    Link operations

  `lookup: bool GET POST PATCH`

    Lookup operations

  `open: bool GET POST PATCH`

    File open operations

  `read: bool GET POST PATCH`

    File read operations

  `rename: bool GET POST PATCH`

    File rename operations

  `rename_dir: bool GET POST PATCH`

    Directory rename operations

  `setattr: bool GET POST PATCH`

    Set attribute operations

  `symlink: bool GET POST PATCH`

    Symbolic link operations

  `write: bool GET POST PATCH`

    File write operations